/**
 * @fileoverview 文件名多单词必须为全小写中划线分隔命名
 * @author fwz
 */
"use strict";

const path = require("path");
//------------------------------------------------------------------------------
// Rule Definition
//------------------------------------------------------------------------------

/** @type {import('eslint').Rule.RuleModule} */
module.exports = {
  meta: {
    type: "suggestion", // `problem`, `suggestion`, or `layout`
    docs: {
      description: "文件名多单词必须为全小写中划线分隔命名",
      recommended: false,
      url: null, // URL to the documentation page for this rule
    },
    fixable: null, // Or `code` or `whitespace`
    schema: [], // Add a schema if the rule has options
    messages: {
      unexpected: '文件名："{{value}}"多单词必须为全小写中划线分隔命名',
    },
  },
  create(context) {
    // variables should be defined here

    //----------------------------------------------------------------------
    // Helpers
    //----------------------------------------------------------------------

    // any helper functions should go here or else delete this section

    //----------------------------------------------------------------------
    // Public
    //----------------------------------------------------------------------

    return {
      // visitor functions for different types of nodes
      "Program:exit"() {
        const fileName = context.getFilename();
        const componentName = path.basename(fileName, path.extname(fileName));
        if (/\.(vue|js|ts)$/.test(path.extname(fileName))) {
          if (!/^[a-z0-9-]+$/.test(componentName)) {
            context.report({
              messageId: "unexpected",
              data: {
                value: componentName,
              },
              loc: { line: 1, column: 0 },
            });
          }
        }
      },
    };
  },
};
